# pylint: skip-file

from textwrap import dedent
from io import StringIO

import pytest

from registrar.config import (
    BackendConfig, HandlerConfig, HandlersConfig, RegistrarConfig, RouteConfig,
    RouteMode
)


@pytest.fixture
def config_simple():
    return StringIO(
        dedent("""
            routes:
              items:
                path: registrar.route.stac.ItemRoute
                queue: register
                success_queue: next_queue
                error_queue: error_queue
                backends:
                  - path: registrar.backend.eoxserver.EOxServerItemBackend
                    kwargs:
                      instance_base_path: /some/dir
                      instance_name: name

                handlers:
                  pre:
                    - path: some.pre.handler
                  post:
                    - path: some.post.handler
                  error:
                    - path: some.error.handler

              collections:
                path: registrar.route.stac.CollectionRoute
                queue: register-collections
                backends:
                  - path: registrar.backend.eoxserver.CollectionBackend

              path:
                path: registrar.route.path.PathRoute
                queue: register-paths
                backends:
                  - path: some.path.backend

            sources: []
        """)
    )


def test_config(config_simple):
    expected = RegistrarConfig(
        {
            "items": RouteConfig(
                "registrar.route.stac.ItemRoute",
                queue="register",
                mode=RouteMode.REGISTER,
                success_queue="next_queue",
                error_queue="error_queue",
                backends=[
                    BackendConfig(
                        "registrar.backend.eoxserver.EOxServerItemBackend",
                        args=[],
                        kwargs={
                            "instance_base_path": "/some/dir",
                            "instance_name": "name"
                        },
                    )
                ],
                handlers=HandlersConfig(
                    [HandlerConfig("some.pre.handler")],
                    [HandlerConfig("some.post.handler")],
                    [HandlerConfig("some.error.handler")],
                )
            ),
            "collections": RouteConfig(
                "registrar.route.stac.CollectionRoute",
                "register-collections",
                backends=[
                    BackendConfig(
                        "registrar.backend.eoxserver.CollectionBackend",
                    )
                ]
            ),
            "path": RouteConfig(
                "registrar.route.path.PathRoute",
                "register-paths",
                backends=[
                    BackendConfig(
                        "some.path.backend",
                    )
                ]
            )
        },
        []
    )
    assert expected == RegistrarConfig.from_file(config_simple)
